@@ -45,6 +45,7 @@ impl Error {
             ErrorKind::InvalidSupportQuery => "Invalid support query".into(),
             ErrorKind::InvalidMediaQuery => "Invalid media query".into(),
             ErrorKind::UnknownAtRuleNotTerminated => "Unknown @rule is not terminated".into(),
+            ErrorKind::InvalidPropertyValue => "Expected a property value".into(),
         };
         handler.struct_span_err(self.inner.0, &msg)
     }
@@ -66,6 +67,7 @@ pub enum ErrorKind {
     UnterminatedBlockComment,
     InvalidTypeSelector,
     InvalidSelector,
+    InvalidPropertyValue,
     ExpectedIdentOrStrForAttrSelectorOp,
     ExpectedNumber,
     InvalidSupportQuery,
