@@ -1,7 +1,10 @@
 #![deny(unused_must_use)]
 
-use lexer::Lexer;
-use parser::{input::TokensInput, PResult, Parser, ParserConfig};
+use crate::{
+    error::Error,
+    lexer::Lexer,
+    parser::{input::TokensInput, PResult, Parser, ParserConfig},
+};
 use swc_common::{input::StringInput, BytePos, SourceFile};
 use swc_css_ast::Tokens;
 
@@ -27,11 +30,15 @@ where
 }
 
 /// Parse a given string as `T`.
+///
+/// If there are syntax errors but if it was recoverable, it will be appendend
+/// to `errors`.
 pub fn parse_str<'a, T>(
     src: &'a str,
     start_pos: BytePos,
     end_pos: BytePos,
     config: ParserConfig,
+    errors: &mut Vec<Error>,
 ) -> PResult<T>
 where
     Parser<Lexer<StringInput<'a>>>: Parse<T>,
@@ -39,27 +46,47 @@ where
     let lexer = Lexer::new(StringInput::new(src, start_pos, end_pos));
     let mut parser = Parser::new(lexer, config);
 
-    parser.parse()
+    let res = parser.parse();
+    errors.extend(parser.take_errors());
+    res
 }
 
 /// Parse a given file as `T`.
-pub fn parse_file<'a, T>(fm: &'a SourceFile, config: ParserConfig) -> PResult<T>
+///
+/// If there are syntax errors but if it was recoverable, it will be appendend
+/// to `errors`.
+pub fn parse_file<'a, T>(
+    fm: &'a SourceFile,
+    config: ParserConfig,
+    errors: &mut Vec<Error>,
+) -> PResult<T>
 where
     Parser<Lexer<StringInput<'a>>>: Parse<T>,
 {
     let lexer = Lexer::new(StringInput::from(fm));
     let mut parser = Parser::new(lexer, config);
 
-    parser.parse()
+    let res = parser.parse();
+    errors.extend(parser.take_errors());
+    res
 }
 
 /// Parse a given file as `T`.
-pub fn parse_tokens<'a, T>(tokens: &'a Tokens, config: ParserConfig) -> PResult<T>
+///
+/// If there are syntax errors but if it was recoverable, it will be appendend
+/// to `errors`.
+pub fn parse_tokens<'a, T>(
+    tokens: &'a Tokens,
+    config: ParserConfig,
+    errors: &mut Vec<Error>,
+) -> PResult<T>
 where
     Parser<TokensInput<'a>>: Parse<T>,
 {
     let lexer = TokensInput::new(tokens);
     let mut parser = Parser::new(lexer, config);
 
-    parser.parse()
+    let res = parser.parse();
+    errors.extend(parser.take_errors());
+    res
 }
